    recipe:

    	status:
    		python3 insurance.py "shows/ingredient_scan_recipe/**/status_*.py"

    	priorities:

    		Calculate the selected unit of the
    		unit kinds first.

    		Then perhaps afterward, convert those
    		units into other units.

    			"mass + mass equivalents": {
    				"per recipe": {
    					"grams": {
    						"fraction string": "0"
    					}
    				}
    			},
    			"biological activity": {
    				"per recipe": {
    					"IU": {
    						"fraction string": "0"
    					}
    				}
    			},
    			"energy": {
    				"per recipe": {
    					"calories": {
    						"fraction string": "0"
    					}
    				}
    			}